@@ -1,7 +1,7 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 1.20 2002/01/19 19:20:45 bkorb Exp $
+ *  $Id: agUtils.c,v 1.21 2002/03/27 05:15:11 bkorb Exp $
  *  This is the main routine for autogen.
  */
 
@@ -713,7 +713,7 @@ checkMem( tMemMgmt* pMM )
             fclose( pfTrace );
             fclose( stdout );
             p = NULL;
-            *p = '~'; /* PAGE FAULT */
+            *p = '~'; /* SEG FAULT */
             _exit( EXIT_FAILURE );
         }
     } while (--ct > 0);
