@@ -1,7 +1,7 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Saturday March 23, 2002 at 01:54:34 PM PST
+ *  It has been AutoGen-ed  Sunday March 31, 2002 at 07:25:46 PM PST
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
@@ -67,7 +67,7 @@
 
 #include "autogen.h"
 #ifndef DEBUG_FSM
-#  undef DEBUG
+#  undef DEBUG_ENABLED
 #endif
 
 /* END   === USER HEADERS === DO NOT CHANGE THIS COMMENT */
@@ -87,7 +87,7 @@
 typedef enum {
     CGI_TR_INVALID,
     CGI_TR_NAME_EQUAL,
-    CGI_TR_SEPERATE,
+    CGI_TR_SEPARATE,
     CGI_TR_STASH,
     CGI_TR_VALUE_ESCAPE,
     CGI_TR_VALUE_SPACE
@@ -130,8 +130,8 @@ static const t_transition cgi_trans_table[ CGI_STATE_CT ][ CGI_EVENT_CT ] = {
     { CGI_ST_VALUE, CGI_TR_VALUE_SPACE },
     { CGI_ST_VALUE, CGI_TR_VALUE_ESCAPE },
     { CGI_ST_VALUE, CGI_TR_STASH },
-    { CGI_ST_INIT, CGI_TR_SEPERATE },
-    { CGI_ST_DONE, CGI_TR_SEPERATE } }
+    { CGI_ST_INIT, CGI_TR_SEPARATE },
+    { CGI_ST_DONE, CGI_TR_SEPARATE } }
 };
 
 
@@ -155,11 +155,11 @@ tSCC zEvEqual[] = "equal";
 tSCC zEvSpace[] = "space";
 tSCC zEvEscape[] = "escape";
 tSCC zEvOther[] = "other";
-tSCC zEvSeperator[] = "seperator";
+tSCC zEvSeparator[] = "separator";
 tSCC zEvEnd[] = "end";
 tSCC* apzEvents[] = {
     zEvAlpha,     zEvName_Char, zEvEqual,     zEvSpace,     zEvEscape,
-    zEvOther,     zEvSeperator, zEvEnd,       zEvInvalid };
+    zEvOther,     zEvSeparator, zEvEnd,       zEvInvalid };
 
 #define CGI_EVT_NAME(t) ( (((unsigned)(t)) >= CGI_EV_INVALID) \
     ? zBogus : apzEvents[ t ])
@@ -225,7 +225,7 @@ cgi_run_fsm(
             case '=': trans_evt = CGI_EV_EQUAL;     break;
             case '+': trans_evt = CGI_EV_SPACE;     break;
             case '%': trans_evt = CGI_EV_ESCAPE;    break;
-            case '&': trans_evt = CGI_EV_SEPERATOR; break;
+            case '&': trans_evt = CGI_EV_SEPARATOR; break;
             default:  trans_evt = CGI_EV_OTHER;     break;
             }
         }
@@ -263,12 +263,12 @@ cgi_run_fsm(
             /* END   == NAME_EQUAL == DO NOT CHANGE THIS COMMENT */
             break;
 
-        case CGI_TR_SEPERATE:
-            /* START == SEPERATE == DO NOT CHANGE THIS COMMENT */
+        case CGI_TR_SEPARATE:
+            /* START == SEPARATE == DO NOT CHANGE THIS COMMENT */
             strcpy( pzOut, "';\n" );
             outlen -= 2;
             pzOut += 3;
-            /* END   == SEPERATE == DO NOT CHANGE THIS COMMENT */
+            /* END   == SEPARATE == DO NOT CHANGE THIS COMMENT */
             break;
 
         case CGI_TR_STASH:
