@@ -1,12 +1,12 @@
 /*  -*- Mode: C -*-
  *
  *  expFormat.c
- *  $Id: expFormat.c,v 1.43 2001/11/21 06:00:41 bkorb Exp $
+ *  $Id: expFormat.c,v 1.42 2002/02/03 03:07:21 bkorb Exp $
  *  This module implements formatting expression functions.
  */
 
 /*
- *  AutoGen copyright 1992-1999 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -145,10 +145,8 @@ ag_scm_dne( SCM prefix, SCM first )
     tCC*     pzFirst = zNil;
     SCM      res;
     tCC*     pzPrefix = ag_scm2zchars( prefix, "prefix" );
-    if (strlen( pzPrefix ) > 128 ) {
-        fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-    }
+    if (strlen( pzPrefix ) > 128 )
+        AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
 
     /*
      *  IF we also have a 'first' prefix string,
@@ -156,30 +154,41 @@ ag_scm_dne( SCM prefix, SCM first )
      */
     if (gh_string_p( first )) {
         int len = SCM_LENGTH( first );
-        if (len >= 128) {
-            fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-            LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-        }
+        if (len >= 128)
+            AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
 
         pzFirst = asprintf( ENABLED_OPT( WRITABLE ) ? "%s\n" : zDne1,
                             ag_scm2zchars( first, "first-prefix" ), pzPrefix );
     }
 
     {
-        time_t    curTime = time( (time_t*)NULL );
+        time_t    curTime = time( NULL );
         struct tm*  pTime = localtime( &curTime );
         strftime( zScribble, 128, "%A %B %e, %Y at %r %Z", pTime );
     }
 
-    pzRes = asprintf( ENABLED_OPT( WRITABLE ) ? zDne2 : zDne,
-                      pzPrefix, pCurFp->pzOutName, zScribble,
-                      OPT_ARG( DEFINITIONS ), pzTemplFileName, pzFirst );
+    {
+        const char* pz;
+        if (! ENABLED_OPT( DEFINITIONS ))
+            pz = "<<no definitions>>";
 
-    if (pzRes == (char*)NULL) {
-        fprintf( stderr, zAllocErr, pzProg, -1, "Do-Not-Edit string" );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zFmtAlloc );
+        else if (*pzOopsPrefix != NUL)
+            pz = "<<CGI-definitions>>";
+
+        else {
+            pz = OPT_ARG( DEFINITIONS );
+            if (strcmp( pz, "-" ) == 0)
+                pz = "stdin";
+        }
+
+        pzRes = asprintf( ENABLED_OPT( WRITABLE ) ? zDne2 : zDne,
+                          pzPrefix, pCurFp->pzOutName, zScribble,
+                          pz, pzTemplFileName, pzFirst );
     }
 
+    if (pzRes == NULL)
+        AG_ABEND( asprintf( zAllocErr, pzProg, -1, "Do-Not-Edit string" ));
+
     res = gh_str02scm( pzRes );
 
     /*
@@ -267,7 +276,7 @@ ag_scm_error( SCM res )
          */
         if (msgLen <= 0)
             abort = PROBLEM;
-        else if (isdigit( *pzMsg ) && (strtol( pzMsg, (char**)NULL, 0 ) == 0))
+        else if (isdigit( *pzMsg ) && (strtol( pzMsg, NULL, 0 ) == 0))
             abort = PROBLEM;
         break;
 
@@ -279,10 +288,15 @@ ag_scm_error( SCM res )
      *  IF there is a message,
      *  THEN print it.
      */
-    if (*pzMsg != NUL)
-        fprintf( stderr, zFmt, (abort != PROBLEM) ? zErr : zWarn,
-                 pCurTemplate->pzFileName, pCurMacro->lineNo,
-                 pCurFp->pzOutName, pzMsg );
+    if (*pzMsg != NUL) {
+        char* pz = asprintf( zFmt, (abort != PROBLEM) ? zErr : zWarn,
+                             pCurTemplate->pzFileName, pCurMacro->lineNo,
+                             pCurFp->pzOutName, pzMsg );
+        if (abort != PROBLEM)
+            AG_ABEND( pz );
+        fputs( pz, pfTrace );
+    }
+
     longjmp( fileAbort, abort );
     /* NOTREACHED */
     return SCM_UNDEFINED;
@@ -291,7 +305,7 @@ ag_scm_error( SCM res )
 
 /*=gfunc gpl
  *
- * what:  GNU public license
+ * what:  GNU General Public License
  * general_use:
  *
  * exparg: prog-name, name of the program under the GPL
@@ -299,7 +313,7 @@ ag_scm_error( SCM res )
  *
  * doc:
  *
- *  Emit a string that contains the GNU Public License.
+ *  Emit a string that contains the GNU General Public License.
  *  It takes two arguments:
  *  @code{prefix} contains the string to start each output line, and
  *  @code{prog_name} contains the name of the program the copyright is
@@ -320,25 +334,19 @@ ag_scm_gpl( SCM prog_name, SCM prefix )
      *  Make sure they are reasonably sized (<256 for program name
      *  and <128 for a line prefix).  Copy them to the scratch buffer.
      */
-    if (SCM_LENGTH( prog_name ) >= 256) {
-        fprintf( stderr, zPfxMsg, zProgLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zProgLen );
-    }
+    if (SCM_LENGTH( prog_name ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zProgLen, 256 ));
 
-    if (SCM_LENGTH( prefix ) >= 128) {
-        fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-    }
+    if (SCM_LENGTH( prefix ) >= 128)
+        AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
 
     /*
      *  Allocate-sprintf the result string, then put it in a new SCM.
      */
     pzRes = asprintf( zGpl, pzPrg, pzPfx );
 
-    if (pzRes == (char*)NULL) {
-        fprintf( stderr, zAllocErr, pzPrg, -1, "GPL string" );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zFmtAlloc );
-    }
+    if (pzRes == NULL)
+        AG_ABEND( asprintf( zAllocErr, pzPrg, -1, "GPL string" ));
 
     res = gh_str02scm( pzRes );
     AGFREE( (void*)pzRes );
@@ -348,20 +356,19 @@ ag_scm_gpl( SCM prog_name, SCM prefix )
 
 /*=gfunc lgpl
  *
- * what:  GNU lib public license
+ * what:  GNU Library General Public License
  * general_use:
  *
  * exparg: prog_name, name of the program under the LGPL
- * exparg: owner, Grantor of the LGPL (obsolete)
+ * exparg: owner, Grantor of the LGPL
  * exparg: prefix, String for starting each output line
  *
  * doc:
  *
- *  Emit a string that contains the GNU Library Public License.  It takes
- *  three arguments:  @code{prefix} contains the string to start each output
- *  line.  @code{owner} contains the copyright owner.  @code{prog_name}
- *  contains the name of the program the copyright is about.
- *
+ *  Emit a string that contains the GNU Library General Public License.
+ *  It takes three arguments:  @code{prefix} contains the string to
+ *  start each output line.  @code{owner} contains the copyright owner.
+ *  @code{prog_name} contains the name of the program the copyright is about.
 =*/
     SCM
 ag_scm_lgpl( SCM prog_name, SCM owner, SCM prefix )
@@ -377,30 +384,22 @@ ag_scm_lgpl( SCM prog_name, SCM owner, SCM prefix )
      *  Make sure they are reasonably sized (<256 for program name
      *  and <128 for a line prefix).  Copy them to the scratch buffer.
      */
-    if (SCM_LENGTH( prog_name ) >= 256) {
-        fprintf( stderr, zPfxMsg, zProgLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zProgLen );
-    }
+    if (SCM_LENGTH( prog_name ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zProgLen, 256 ));
 
-    if (SCM_LENGTH( prefix ) >= 128) {
-        fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-    }
+    if (SCM_LENGTH( prefix ) >= 128)
+        AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
 
-    if (SCM_LENGTH( owner ) >= 256) {
-        fprintf( stderr, zPfxMsg, zOwnLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zOwnLen );
-    }
+    if (SCM_LENGTH( owner ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zOwnLen, 256 ));
 
     /*
      *  Allocate-sprintf the result string, then put it in a new SCM.
      */
     pzRes = asprintf( zLgpl, pzPrg, pzPfx, pzOwner );
 
-    if (pzRes == (char*)NULL) {
-        fprintf( stderr, zAllocErr, pzPrg, -1, "LGPL string" );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zFmtAlloc );
-    }
+    if (pzRes == NULL)
+        AG_ABEND( asprintf( zAllocErr, pzPrg, -1, "LGPL string" ));
 
     res = gh_str02scm( pzRes );
     AGFREE( (void*)pzRes );
@@ -410,7 +409,7 @@ ag_scm_lgpl( SCM prog_name, SCM owner, SCM prefix )
 
 /*=gfunc bsd
  *
- * what:  Free BSD public license
+ * what:  BSD Public License
  * general_use:
  *
  * exparg: prog_name, name of the program under the BSD
@@ -446,30 +445,22 @@ ag_scm_bsd( SCM prog_name, SCM owner, SCM prefix )
      *  Make sure they are reasonably sized (<256 for program name
      *  and <128 for a line prefix).  Copy them to the scratch buffer.
      */
-    if (SCM_LENGTH( prog_name ) >= 256) {
-        fprintf( stderr, zPfxMsg, zProgLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zProgLen );
-    }
+    if (SCM_LENGTH( prog_name ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zProgLen, 256 ));
 
-    if (SCM_LENGTH( prefix ) >= 128) {
-        fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-    }
+    if (SCM_LENGTH( prefix ) >= 128)
+        AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
 
-    if (SCM_LENGTH( owner ) >= 256) {
-        fprintf( stderr, zPfxMsg, zOwnLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zOwnLen );
-    }
+    if (SCM_LENGTH( owner ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zOwnLen, 256 ));
 
     /*
      *  Allocate-sprintf the result string, then put it in a new SCM.
      */
     pzRes = asprintf( zBsd, pzPrg, pzPfx, pzOwner );
 
-    if (pzRes == (char*)NULL) {
-        fprintf( stderr, zAllocErr, pzPrg, -1, "BSD string" );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zFmtAlloc );
-    }
+    if (pzRes == NULL)
+        AG_ABEND( asprintf( zAllocErr, pzPrg, -1, "BSD string" ));
 
     res = gh_str02scm( pzRes );
     AGFREE( (void*)pzRes );
@@ -523,7 +514,7 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
         else if (strcmp( mi.pzFileName, pzLicense ) != 0) {
             munmap( mi.pData, mi.size );
             close( mi.fd );
-            mi.pData = (char*)NULL;
+            mi.pData = NULL;
             free( (void*)mi.pzFileName );
             mi.pzFileName = pzLicense;
         }
@@ -532,7 +523,7 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
     /*
      *  Make sure the data are loaded and trim any white space
      */
-    if (mi.pData == (char*)NULL) {
+    if (mi.pData == NULL) {
         char* pz;
         tSCC*  apzSfx[] = { "lic", NULL };
 
@@ -548,27 +539,21 @@ ag_scm_license( SCM license, SCM prog_name, SCM owner, SCM prefix )
      *  Make sure they are reasonably sized (<256 for program name
      *  and <128 for a line prefix).  Copy them to the scratch buffer.
      */
-    if (SCM_LENGTH( prog_name ) >= 256) {
-        fprintf( stderr, zPfxMsg, zProgLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zProgLen );
-    }
-    if (SCM_LENGTH( prefix ) >= 128) {
-        fprintf( stderr, zPfxMsg, zPfxLen, 128 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zPfxLen );
-    }
-    if (SCM_LENGTH( owner ) >= 256) {
-        fprintf( stderr, zPfxMsg, zOwnLen, 256 );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zOwnLen );
-    }
+    if (SCM_LENGTH( prog_name ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zProgLen, 256 ));
+
+    if (SCM_LENGTH( prefix ) >= 128)
+        AG_ABEND( asprintf( zPfxMsg, zPfxLen, 128 ));
+
+    if (SCM_LENGTH( owner ) >= 256)
+        AG_ABEND( asprintf( zPfxMsg, zOwnLen, 256 ));
 
     /*
      *  Reformat the string with the given arguments
      */
     pzRes = asprintf( (char*)mi.pData, pzPrg, pzOwner );
-    if (pzRes == (char*)NULL) {
-        fprintf( stderr, zAllocErr, pzPrg, -1, "license string" );
-        LOAD_ABORT( pCurTemplate, pCurMacro, zFmtAlloc );
-    }
+    if (pzRes == NULL)
+        AG_ABEND( asprintf( zAllocErr, pzPrg, -1, "license string" ));
 
     {
         int     pfx_size = strlen( pzPfx );
