@@ -1,7 +1,7 @@
 
 /*
  *  expString.c
- *  $Id: expString.c,v 1.42 2002/01/31 04:07:05 bkorb Exp $
+ *  $Id: expString.c,v 1.43 2002/03/27 05:15:11 bkorb Exp $
  *  This module implements expression functions that
  *  manipulate string values.
  */
@@ -719,7 +719,7 @@ ag_scm_shellf( SCM fmt, SCM alist )
     int   len = scm_ilength( alist );
     char* pz;
 
-#ifdef DEBUG
+#ifdef DEBUG_ENABLED
     if (len < 0)
         AG_ABEND( "invalid alist to shellf" );
 #endif
