@@ -1,12 +1,12 @@
 
 /*
- *  $Id: funcIf.c,v 1.20 2001/11/03 22:46:44 bkorb Exp $
+ *  $Id: funcIf.c,v 1.20 2002/01/19 19:20:45 bkorb Exp $
  *
  *  This module implements the _IF text function.
  */
 
 /*
- *  AutoGen copyright 1992-2001 Bruce Korb
+ *  AutoGen copyright 1992-2002 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -46,7 +46,7 @@ STATIC ag_bool eval_true( void );
  *  4.  For its length or its first five characters (whichever is less)
  *      it matches the string "false"
  */
-    STATIC ag_bool
+STATIC ag_bool
 eval_true( void )
 {
     ag_bool needFree;
@@ -128,7 +128,7 @@ eval_true( void )
  *    This macro ends the @code{IF} function template block.
  *    For a complete description @xref{IF}.
 =*/
-    tMacro*
+tMacro*
 mFunc_If( tTemplate* pT, tMacro* pMac )
 {
     tMacro* pRet = pT->aMacros + pMac->endIndex;
@@ -210,7 +210,7 @@ mFunc_If( tTemplate* pT, tMacro* pMac )
  *    This macro ends the @code{WHILE} function template block.
  *    For a complete description @xref{WHILE}.
 =*/
-    tMacro*
+tMacro*
 mFunc_While( tTemplate* pT, tMacro* pMac )
 {
     tMacro* pRet = pT->aMacros + pMac->endIndex;
@@ -264,11 +264,11 @@ STATIC tLoadProc mLoad_Elif, mLoad_Else;
  *    @code{IF} function.  Its expression argument is evaluated as are
  *    the arguments to @code{IF}.  For a complete description @xref{IF}.
 =*/
-    tMacro*
+STATIC tMacro*
 mLoad_Elif( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     if ((int)pMac->res == 0)
-        LOAD_ABORT( pT, pMac, zNoIfExpr );
+        AG_ABEND_IN( pT, pMac, zNoIfExpr );
     /*
      *  Load the expression
      */
@@ -290,16 +290,16 @@ mLoad_Elif( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
  *    It denotes the start of an alternate template block for
  *    the @code{IF} function.  For a complete description @xref{IF}.
 =*/
-    tMacro*
+STATIC tMacro*
 mLoad_Else( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     /*
      *  After processing an "ELSE" macro,
      *  we have a special handler function for 'ENDIF' only.
      */
-    static tpLoadProc apElseLoad[ FUNC_CT ] = { (tpLoadProc)NULL };
+    static tpLoadProc apElseLoad[ FUNC_CT ] = { NULL };
 
-    if (apElseLoad[0] == (tpLoadProc)NULL) {
+    if (apElseLoad[0] == NULL) {
         memcpy( (void*)apElseLoad, apLoadProc, sizeof( apLoadProc ));
         apElseLoad[ FTYP_ENDIF ] = &mLoad_Ending;
     }
@@ -314,11 +314,15 @@ mLoad_Else( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 
 
-    tMacro*
+/*
+ *  mLoad_Ending is the common block termination function.
+ *  By returning NULL, it tells the macro parsing loop to return.
+ */
+tMacro*
 mLoad_Ending( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
     memset( (void*)pMac, 0, sizeof( *pMac ));
-    return (tMacro*)NULL;
+    return NULL;
 }
 
 
@@ -336,16 +340,16 @@ mLoad_If( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  we have handler functions for 'ELIF', 'ELSE' and 'ENDIF'
      *  Otherwise, we do not.  Switch the callout function table.
      */
-    static tpLoadProc apIfLoad[ FUNC_CT ] = { (tpLoadProc)NULL };
+    static tpLoadProc apIfLoad[ FUNC_CT ] = { NULL };
 
     /*
      *  IF there is no associated text expression
      *  THEN woops!  what are we to case on?
      */
     if (srcLen == 0)
-        LOAD_ABORT( pT, pMac, zNoIfExpr );
+        AG_ABEND_IN( pT, pMac, zNoIfExpr );
 
-    if (apIfLoad[0] == (tpLoadProc)NULL) {
+    if (apIfLoad[0] == NULL) {
         memcpy( (void*)apIfLoad, apLoadProc, sizeof( apLoadProc ));
         apIfLoad[ FTYP_ELIF ]  = &mLoad_Elif;
         apIfLoad[ FTYP_ELSE ]  = &mLoad_Else;
@@ -372,9 +376,9 @@ mLoad_If( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  to return with the text scanning pointer pointing
      *  to the remaining text.
      */
-    pEndifMac = parseTemplate( pT, pMac+1, ppzScan );
-    if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "ENDIF not found" );
+    pEndifMac = parseTemplate( pMac+1, ppzScan );
+    if (*ppzScan == NULL)
+        AG_ABEND_IN( pT, pMac, "ENDIF not found" );
 
     current_if.pIf->endIndex   = \
     current_if.pElse->sibIndex = pEndifMac - pT->aMacros;
@@ -401,16 +405,16 @@ mLoad_While( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  we have handler functions for 'ELIF', 'ELSE' and 'ENDIF'
      *  Otherwise, we do not.  Switch the callout function table.
      */
-    static tpLoadProc apWhileLoad[ FUNC_CT ] = { (tpLoadProc)NULL };
+    static tpLoadProc apWhileLoad[ FUNC_CT ] = { NULL };
 
     /*
      *  IF there is no associated text expression
      *  THEN woops!  what are we to case on?
      */
     if (srcLen == 0)
-        LOAD_ABORT( pT, pMac, "expressionless WHILE" );
+        AG_ABEND_IN( pT, pMac, "expressionless WHILE" );
 
-    if (apWhileLoad[0] == (tpLoadProc)NULL) {
+    if (apWhileLoad[0] == NULL) {
         memcpy( (void*)apWhileLoad, apLoadProc, sizeof( apLoadProc ));
         apWhileLoad[ FTYP_ENDWHILE ] = &mLoad_Ending;
     }
@@ -428,9 +432,9 @@ mLoad_While( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
      *  to return with the text scanning pointer pointing to the remaining
      *  text.
      */
-    pEndMac = parseTemplate( pT, pMac+1, ppzScan );
-    if (*ppzScan == (char*)NULL)
-        LOAD_ABORT( pT, pMac, "ENDWHILE not found" );
+    pEndMac = parseTemplate( pMac+1, ppzScan );
+    if (*ppzScan == NULL)
+        AG_ABEND_IN( pT, pMac, "ENDWHILE not found" );
 
     pMac->sibIndex = pMac->endIndex = pEndMac - pT->aMacros;
 
@@ -463,7 +467,7 @@ ag_scm_set_writable( SCM set )
     switch (STATE_OPT( WRITABLE )) {
     case OPTST_DEFINED:
     case OPTST_PRESET:
-        fprintf( stderr, zWarn, pCurTemplate->pzFileName, pCurMacro->lineNo );
+        fprintf( pfTrace, zWarn, pCurTemplate->pzFileName, pCurMacro->lineNo );
         break;
 
     default:
